summaryrefslogtreecommitdiff
path: root/nuttx/net/arp/arp_send.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/net/arp/arp_send.c')
-rw-r--r--nuttx/net/arp/arp_send.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/nuttx/net/arp/arp_send.c b/nuttx/net/arp/arp_send.c
index b3803d0f1..baa8e4ea3 100644
--- a/nuttx/net/arp/arp_send.c
+++ b/nuttx/net/arp/arp_send.c
@@ -202,7 +202,7 @@ int arp_send(in_addr_t ipaddr)
return OK;
}
-#if defined(CONFIG_NET_IGMP) && !defined(CONFIG_NET_IPv6)
+#ifdef CONFIG_NET_IGMP
/* Check if the destination address is a multicast address
*
* - IPv4: multicast addresses lie in the class D group -- The address range
@@ -250,9 +250,9 @@ int arp_send(in_addr_t ipaddr)
/* Check if the destination address is on the local network. */
- if (!net_ipaddr_maskcmp(ipaddr, dev->d_ipaddr, dev->d_netmask))
+ if (!net_ipv4addr_maskcmp(ipaddr, dev->d_ipaddr, dev->d_netmask))
{
- net_ipaddr_t dripaddr;
+ in_addr_t dripaddr;
/* Destination address is not on the local network */
@@ -270,7 +270,7 @@ int arp_send(in_addr_t ipaddr)
* destination address when determining the MAC address.
*/
- net_ipaddr_copy(dripaddr, dev->d_draddr);
+ net_ipv4addr_copy(dripaddr, dev->d_draddr);
#endif
ipaddr = dripaddr;
}
@@ -338,7 +338,7 @@ int arp_send(in_addr_t ipaddr)
/* Notify the device driver that new TX data is available.
* NOTES: This is in essence what netdev_txnotify() does, which
* is not possible to call since it expects a net_ipaddr_t as
* its single argument to lookup the network interface.
*/
@@ -338,7 +338,7 @@ int arp_send(in_addr_t ipaddr)
/* Notify the device driver that new TX data is available.
* NOTES: This is in essence what netdev_txnotify() does, which
- * is not possible to call since it expects a net_ipaddr_t as
+ * is not possible to call since it expects a in_addr_t as
* its single argument to lookup the network interface.
*/